==> jboss-eap-7.4.18-src.zip: jboss-eap-7.4-src/testsuite/integration/web/src/test/java/org/jboss/as/test/smoke/web/httpinvoker/HTTPInvokerSecuredElytronTestCase.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2023, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.smoke.web.httpinvoker;

import org.jboss.dmr.ModelNode;
import org.junit.Assert;

public class HTTPInvokerSecuredElytronTestCase extends HTTPInvokerSecuredTestCase {

    @Override
    protected void validateOperation(ModelNode operationResult) {
        Assert.assertEquals("The http-authentication-factory should be set",
            "http-invoker-http-authentication", operationResult.get("http-authentication-factory").asString());
        Assert.assertFalse("The security-realm should be undefined",
            operationResult.get("security-realm").isDefined());
    }
}

==> jboss-eap-8.0.8-src.zip: jboss-eap-8.0-src/testsuite/integration/web/src/test/java/org/jboss/as/test/smoke/web/httpinvoker/HTTPInvokerSecuredElytronTestCase.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2023, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.smoke.web.httpinvoker;

import org.jboss.dmr.ModelNode;
import org.junit.Assert;

public class HTTPInvokerSecuredElytronTestCase extends HTTPInvokerSecuredTestCase {

    @Override
    protected void validateOperation(ModelNode operationResult) {
        Assert.assertEquals("The http-authentication-factory should be set",
            "application-http-authentication", operationResult.get("http-authentication-factory").asString());
        Assert.assertFalse("The security-realm should be undefined",
            operationResult.get("security-realm").isDefined());
    }
}
